@@ -25,7 +25,7 @@ GUILD_ADMIN: Permission = Permission(_guild_admin)
 
 async def msg_rule(event: Union[GroupMessageEvent, GuildMessageEvent]) -> bool:
     """Rule 消息规则"""
-    for per_server in get_mc_qq_servers_list():
+    for per_server in mc_qq_servers_list:
         if isinstance(event, GroupMessageEvent):
             if event.group_id in per_server['group_list']:
                 return True
@@ -35,14 +35,25 @@ async def msg_rule(event: Union[GroupMessageEvent, GuildMessageEvent]) -> bool:
     return False
 
 
+async def msg_to_qq_process(json_msg):
+    """处理来自MC的消息，并返回处理后的消息"""
+    message = {
+        "PlayerJoinEvent": f"{json_msg['player']['nickname']} 加入了服务器",
+        "PlayerQuitEvent": f"{json_msg['player']['nickname']} 离开了服务器",
+        "AsyncPlayerChatEvent": f"{json_msg['player']['nickname']} 说：{json_msg['message']}",
+        "PlayerDeathEvent": f"{json_msg['message']}",
+    }
+    return message[json_msg['event_name']]
+
+
 async def send_msg_to_qq(bot: Bot, json_msg):
     """发送消息到 QQ"""
-    msg = json_msg['message']['data']
-    if get_mc_qq_display_server_name():
-        msg = f"[{json_msg['server_name']}] {json_msg['message']['data']}"
+    msg = await msg_to_qq_process(json_msg)
+    if mc_qq_display_server_name:
+        msg = f"[{json_msg['server_name']}] {msg}"
     # 循环服务器列表并发送消息
-    if get_mc_qq_servers_list():
-        for per_server in get_mc_qq_servers_list():
+    if mc_qq_servers_list:
+        for per_server in mc_qq_servers_list:
             # 如果服务器名相同
             if per_server['server_name'] == json_msg['server_name']:
                 # 如果群列表存在
@@ -124,50 +135,57 @@ async def msg_process(bot: Bot, event: Union[GroupMessageEvent, GuildMessageEven
     for msg in event.message:
         # 文本
         if msg.type == "text":
-            msg_dict = {"text": msg.data['text'].replace("\r\n", " "), "color": "white"}
-            text_msg += msg.data['text'].replace("\r\n", " ")
+            msg_dict = {"text": msg.data['text'].replace("\r", "").replace("\n", "\n * ") + " ", "color": "white"}
+            text_msg += msg.data['text'].replace("\r", "").replace("\n", "\n * ")
         # 图片
         elif msg.type == "image":
             msg_dict = {"text": "[图片] ", "color": "yellow",
                         "clickEvent": {"action": "open_url", "value": msg.data['url']},
-                        "hoverEvent": {"action": "show_text", "contents": [{"text": "查看图片", "color": "gold"}]}}
-            text_msg += '[图片] '
+                        "hoverEvent": {"action": "show_text", "contents": [{"text": "查看图片", "color": "gold"}]}
+                        }
+            text_msg += '[图片]'
         # 表情
         elif msg.type == "face":
-            msg_dict = {"text": "[表情]", "color": "gold"}
-            text_msg += '[表情] '
+            msg_dict = {"text": "[表情] ", "color": "gold"}
+            text_msg += '[表情]'
         # 语音
         elif msg.type == "record":
-            msg_dict = {"text": "[语音]", "color": "light_purple"}
-            text_msg += '[语音] '
+            msg_dict = {"text": "[语音] ", "color": "light_purple"}
+            text_msg += '[语音]'
         # 视频
         elif msg.type == "video":
             msg_dict = {"text": "[视频] ", "color": "light_purple",
                         "clickEvent": {"action": "open_url", "value": msg.data['url']},
-                        "hoverEvent": {"action": "show_text", "contents": [{"text": "查看视频", "color": "dark_purple"}]}}
-            text_msg += '[视频] '
+                        "hoverEvent": {"action": "show_text", "contents": [{"text": "查看视频", "color": "dark_purple"}]}
+                        }
+            text_msg += '[视频]'
         # @
         elif msg.type == "at":
             # 获取被@ 群/频道 昵称
             at_member_nickname = await get_member_nickname(bot, event, msg.data['qq'])
             msg_dict = {"text": "@" + at_member_nickname + " ", "color": "green"}
-            text_msg += f"@{at_member_nickname} "
+            text_msg += f"@{at_member_nickname}"
         # share
         elif msg.type == "share":
             msg_dict = {"text": "[分享：" + msg.data['title'] + "] ", "color": "yellow",
                         "clickEvent": {"action": "open_url", "value": msg.data['url']},
-                        "hoverEvent": {"action": "show_text", "contents": [{"text": "查看图片", "color": "gold"}]}}
-            text_msg += '[分享：' + msg.data['title'] + '] '
+                        "hoverEvent": {"action": "show_text", "contents": [{"text": "查看图片", "color": "gold"}]}
+                        }
+            text_msg += '[分享：' + msg.data['title'] + ']'
         # forward
         elif msg.type == "forward":
             # TODO 将合并转发消息拼接为字符串
             # 获取合并转发 await bot.get_forward_msg(message_id=event.message_id)
             msg_dict = {"text": "[合并转发] ", "color": "white"}
-            text_msg += '[合并转发] '
+            text_msg += '[合并转发]'
         else:
             msg_dict = {"text": "[ " + msg.type + "] ", "color": "white"}
-            text_msg += '[' + msg.type + '] '
+            text_msg += '[' + msg.type + ']'
+
+        # 放入消息列表
         message_list.append(msg_dict)
+
+    # 拼接完整命令
     command_msg += json.dumps(message_list)
     return text_msg, command_msg
 
@@ -234,3 +252,8 @@ def get_mc_qq_mcrcon_guild_admin_roles() -> list:
         return list(get_driver().config.mc_qq_mcrcon_guild_admin_roles)
     except AttributeError:
         return ["频道主", "管理员"]
+
+
+mc_qq_display_server_name = get_mc_qq_display_server_name()
+mc_qq_servers_list = get_mc_qq_servers_list()
+mc_qq_mcrcon_rcon_list = get_mc_qq_mcrcon_rcon_list()
